==> ejc-other-impl-3.0.0-20221026.010330-18-sources.jar: com/ejianc/business/other/service/impl/OtherContractChangeBpmServiceImpl.java <==
package com.ejianc.business.other.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.other.bean.*;
import com.ejianc.business.other.service.*;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

@Service("otherContractChange")
public class OtherContractChangeBpmServiceImpl implements ICommonBusinessService {
    @Autowired
    private IOtherContractChangeService changeService;
    @Autowired
    private IOtherContractDetailChangeService changeDetailService;
    @Autowired
    private IOtherContractClauseChangeService changeClauseService;
    @Autowired
    private IOtherContractService contractService;
    @Autowired
    private IOtherContractDetailService contractDetailService;
    @Autowired
    private IOtherContractPayPlanService contractPayPlanService;
    @Autowired
    private IOtherContractClauseService contractClauseService;
    @Autowired
    private IOtherContractHistoryService historyService;
    @Autowired
    private IOtherContractDetailHistoryService historyDetailService;
    @Autowired
    private IOtherContractPayPlanHistoryService historyPayPlanService;
    @Autowired
    private IOtherContractClauseHistoryService historyClauseService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    @Transactional
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //变更表
        OtherContractChangeEntity entity = changeService.selectById(billId);
        //合同主表
        OtherContractEntity contractEntity = contractService.selectById(entity.getContractId());

        saveHistory(entity, contractEntity);

        //回写合同主表
        contractEntity.setBeforeChangeTaxMny(contractEntity.getContractTaxMny());//变更后金额变为变更前金额
        contractEntity.setBeforeChangeMny(contractEntity.getContractMny());//变更后金额变为变更前金额
        contractEntity.setContractTaxMny(contractEntity.getChangingTaxMny());//变更中金额变为变更后金额
        contractEntity.setContractMny(contractEntity.getChangingMny());//变更中金额变为变更后金额
        contractEntity.setChangingTaxMny(null);//变更中金额清空
        contractEntity.setChangingMny(null);//变更中金额清空
        contractEntity.setChangeStatus(3);//状态改为已变更
        contractEntity.setChangeCode(contractEntity.getChangeCode());
        contractEntity.setChangeId(contractEntity.getChangeId());
        contractEntity.setBillState(contractEntity.getBillState());
        contractEntity.setSumInvoicingTaxMny(contractEntity.getSumInvoicingTaxMny());
        contractEntity.setSumInvoicingMny(contractEntity.getSumInvoicingMny());

        contractEntity.setProjectId(entity.getProjectId());
        contractEntity.setProjectName(entity.getProjectName());
        contractEntity.setContractName(entity.getContractName());
        contractEntity.setBillCode(entity.getBillCode());
        contractEntity.setOrgId(entity.getOrgId());
        contractEntity.setOrgName(entity.getOrgName());
        contractEntity.setContractStatus(entity.getContractStatus());
        contractEntity.setCustomerId(entity.getCustomerId());
        contractEntity.setCustomerName(entity.getCustomerName());
        contractEntity.setSupplierId(entity.getSupplierId());
        contractEntity.setSupplierName(entity.getSupplierName());
        contractEntity.setContractType(entity.getContractType());
        contractEntity.setTaxRate(entity.getTaxRate());
        contractEntity.setSignDate(entity.getSignDate());
        contractEntity.setEmployeeId(entity.getEmployeeId());
        contractEntity.setEmployeeName(entity.getEmployeeName());
        contractEntity.setMemo(entity.getMemo());
        contractEntity.setTaxMny(entity.getTaxMny());

        contractEntity.setChangeReason(entity.getChangeReason());

        contractEntity.setChangeVersion(entity.getChangeVersion());
        contractService.saveOrUpdate(contractEntity);

        savechangeBack(entity,contractEntity.getId());

        //entity.setBillState();
        entity.setUsedTime(new Date());
        entity.setBeforeContractName(contractEntity.getContractName());
        changeService.saveOrUpdate(entity, false);
        return CommonResponse.success();
    }


    private void saveHistory(OtherContractChangeEntity entity, OtherContractEntity contractEntity) {
        //同步原合同到记录表
        OtherContractHistoryEntity historyEntity = BeanMapper.map(contractEntity, OtherContractHistoryEntity.class);
        historyEntity.setContractId(entity.getContractId());//原合同主键
        historyEntity.setId(null);
        historyService.save(historyEntity);

        //同步原清单到记录表
        List<OtherContractDetailEntity> checkList = contractEntity.getDetailVos();
        if (null != checkList && checkList.size() > 0) {
            List<OtherContractDetailHistoryEntity> historyDetails = BeanMapper.mapList(checkList, OtherContractDetailHistoryEntity.class);
            for (OtherContractDetailHistoryEntity hde : historyDetails) {
                hde.setHistoryId(historyEntity.getId());//记录表主键
                hde.setContractId(entity.getContractId());//原合同主键
                hde.setId(null);
            }
            historyDetailService.saveOrUpdateBatch(historyDetails, historyDetails.size(), false);
        }

        List<OtherContractPayPlanEntity> payPlanList = contractEntity.getPayPlanVos();
        if (null != payPlanList && payPlanList.size() > 0) {
            List<OtherContractPayPlanHistoryEntity> historypayPlan = BeanMapper.mapList(payPlanList, OtherContractPayPlanHistoryEntity.class);
            for (OtherContractPayPlanHistoryEntity hce : historypayPlan) {
                hce.setHistoryId(historyEntity.getId());//记录表主键
                hce.setContractId(entity.getContractId());//原合同主键
                hce.setId(null);
            }
            historyPayPlanService.saveOrUpdateBatch(historypayPlan, historypayPlan.size(), false);
        }

        //同步原条款到记录表
        List<OtherContractClauseEntity> clauseList = contractEntity.getClauseVos();
        if (null != clauseList && clauseList.size() > 0) {
            List<OtherContractClauseHistoryEntity> historyClauses = BeanMapper.mapList(clauseList, OtherContractClauseHistoryEntity.class);
            for (OtherContractClauseHistoryEntity hce : historyClauses) {
                hce.setHistoryId(historyEntity.getId());//记录表主键
                hce.setContractId(entity.getContractId());//原合同主键
                hce.setId(null);
            }
            historyClauseService.saveOrUpdateBatch(historyClauses, historyClauses.size(), false);
        }
    }

    private void savechangeBack(OtherContractChangeEntity entity,Long contractId) {
        //回写原合同清单表
        contractDetailService.deleteByContractId(entity.getContractId());
        List<OtherContractDetailChangeEntity> changeDetailList = entity.getDetailVos();
        if (null != changeDetailList && changeDetailList.size() > 0) {
            List<OtherContractDetailEntity> detailList = BeanMapper.mapList(changeDetailList, OtherContractDetailEntity.class);
            for (OtherContractDetailEntity cde : detailList) {
                cde.setChangeBid(cde.getId());
                cde.setContractId(contractId);
                cde.setId(null);
                //变更类型如果是中止，不能改类型
                if (null == cde.getChangeType() || cde.getChangeType() != 5) {
                    cde.setChangeType(0);
                }
            }
            contractDetailService.saveOrUpdateBatch(detailList, detailList.size(), false);
        }

        List<OtherContractPayPlanChangeEntity> changePayPlanList = entity.getPayPlanVos();
        contractPayPlanService.remove(new QueryWrapper<OtherContractPayPlanEntity>().eq("contract_id", entity.getContractId()), false);
        if (null != changePayPlanList && changePayPlanList.size() > 0) {
            List<OtherContractPayPlanEntity> contractClauses = BeanMapper.mapList(changePayPlanList, OtherContractPayPlanEntity.class);
            for (OtherContractPayPlanEntity cce : contractClauses) {
                cce.setContractId(contractId);
                cce.setId(null);
            }
            contractPayPlanService.saveOrUpdateBatch(contractClauses, contractClauses.size(), false);
        }
        //回写原合同条款表
        List<OtherContractClauseChangeEntity> changeClauseList = entity.getClauseVos();
        contractClauseService.remove(new QueryWrapper<OtherContractClauseEntity>().eq("contract_id", entity.getContractId()), false);
        if (null != changeClauseList && changeClauseList.size() > 0) {
            List<OtherContractClauseEntity> contractClauses = BeanMapper.mapList(changeClauseList, OtherContractClauseEntity.class);
            for (OtherContractClauseEntity cce : contractClauses) {
                cce.setContractId(contractId);
                cce.setId(null);
            }
            contractClauseService.saveOrUpdateBatch(contractClauses, contractClauses.size(), false);
        }
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.error("合同变更单暂不支持回退功能!");
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}

==> ejc-other-impl-3.0.0-20231108.084525-102-sources.jar: com/ejianc/business/other/service/impl/OtherContractChangeBpmServiceImpl.java <==
package com.ejianc.business.other.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.other.bean.*;
import com.ejianc.business.other.service.*;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;

@Service("otherContractChange")
public class OtherContractChangeBpmServiceImpl implements ICommonBusinessService {
    @Autowired
    private IOtherContractChangeService changeService;
    @Autowired
    private IOtherContractDetailChangeService changeDetailService;
    @Autowired
    private IOtherContractClauseChangeService changeClauseService;
    @Autowired
    private IOtherContractService contractService;
    @Autowired
    private IOtherContractDetailService contractDetailService;
    @Autowired
    private IOtherContractPayPlanService contractPayPlanService;
    @Autowired
    private IOtherContractClauseService contractClauseService;
    @Autowired
    private IOtherContractHistoryService historyService;
    @Autowired
    private IOtherContractDetailHistoryService historyDetailService;
    @Autowired
    private IOtherContractPayPlanHistoryService historyPayPlanService;
    @Autowired
    private IOtherContractClauseHistoryService historyClauseService;

    /**
     * 提交前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    ;

    /**
     * 提交完回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 有审批流的撤回前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 有审批流的撤回后回调
     *
     * @param
     * @return
     */
    @Override
    public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.success();
    }

    ;

    /**
     * 审批节点审批中时节点审批前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
        return CommonResponse.success();
    }

    ;

    /**
     * 终审审核前回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

    /**
     * 终审审核完回调
     *
     * @param
     * @return
     */
    @Override
    @Transactional
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
        //变更表
        OtherContractChangeEntity entity = changeService.selectById(billId);
        //合同主表
        OtherContractEntity contractEntity = contractService.selectById(entity.getContractId());

        saveHistory(entity, contractEntity);

        //回写合同主表
        contractEntity.setBeforeChangeTaxMny(contractEntity.getContractTaxMny());//变更后金额变为变更前金额
        contractEntity.setBeforeChangeMny(contractEntity.getContractMny());//变更后金额变为变更前金额
        contractEntity.setContractTaxMny(contractEntity.getChangingTaxMny());//变更中金额变为变更后金额
        contractEntity.setContractMny(contractEntity.getChangingMny());//变更中金额变为变更后金额
        contractEntity.setChangingTaxMny(null);//变更中金额清空
        contractEntity.setChangingMny(null);//变更中金额清空
        contractEntity.setChangeStatus(3);//状态改为已变更
        contractEntity.setChangeCode(contractEntity.getChangeCode());
        contractEntity.setChangeId(contractEntity.getChangeId());
        contractEntity.setBillState(contractEntity.getBillState());
        contractEntity.setSumInvoicingTaxMny(contractEntity.getSumInvoicingTaxMny());
        contractEntity.setSumInvoicingMny(contractEntity.getSumInvoicingMny());

        contractEntity.setProjectId(entity.getProjectId());
        contractEntity.setProjectName(entity.getProjectName());
        contractEntity.setContractName(entity.getContractName());
        contractEntity.setBillCode(entity.getBillCode());
        contractEntity.setOrgId(entity.getOrgId());
        contractEntity.setOrgName(entity.getOrgName());
        contractEntity.setContractStatus(entity.getContractStatus());
        contractEntity.setCustomerId(entity.getCustomerId());
        contractEntity.setCustomerName(entity.getCustomerName());
        contractEntity.setSupplierId(entity.getSupplierId());
        contractEntity.setSupplierName(entity.getSupplierName());
        contractEntity.setContractType(entity.getContractType());
        contractEntity.setTaxRate(entity.getTaxRate());
        contractEntity.setSignDate(entity.getSignDate());
        contractEntity.setEmployeeId(entity.getEmployeeId());
        contractEntity.setEmployeeName(entity.getEmployeeName());
        contractEntity.setMemo(entity.getMemo());
        contractEntity.setTaxMny(entity.getTaxMny());
        contractEntity.setContractUndiscountMny(entity.getContractUndiscountMny());
        contractEntity.setDiscountMny(entity.getDiscountMny());

        contractEntity.setChangeReason(entity.getChangeReason());

        contractEntity.setChangeVersion(entity.getChangeVersion());
        boolean b = contractService.saveOrUpdate(contractEntity);

        savechangeBack(entity,contractEntity.getId());

        //entity.setBillState();
        entity.setUsedTime(new Date());
        entity.setBeforeContractName(contractEntity.getContractName());
        changeService.saveOrUpdate(entity, false);

        //更新询价合同签订金额
        if (b) {
            contractService.countContractNumAndMnyByEnquiry(contractEntity.getEnquiryPriceBillId());
        }
        return CommonResponse.success();
    }


    private void saveHistory(OtherContractChangeEntity entity, OtherContractEntity contractEntity) {
        //同步原合同到记录表
        OtherContractHistoryEntity historyEntity = BeanMapper.map(contractEntity, OtherContractHistoryEntity.class);
        historyEntity.setContractId(entity.getContractId());//原合同主键
        historyEntity.setId(null);
        historyEntity.setContractUndiscountMny(contractEntity.getContractUndiscountMny());
        historyEntity.setDiscountMny(contractEntity.getDiscountMny());
        historyService.save(historyEntity);

        //同步原清单到记录表
        List<OtherContractDetailEntity> checkList = contractEntity.getDetailVos();
        if (null != checkList && checkList.size() > 0) {
            List<OtherContractDetailHistoryEntity> historyDetails = BeanMapper.mapList(checkList, OtherContractDetailHistoryEntity.class);
            for (OtherContractDetailHistoryEntity hde : historyDetails) {
                hde.setHistoryId(historyEntity.getId());//记录表主键
                hde.setContractId(entity.getContractId());//原合同主键
                hde.setId(null);
            }
            historyDetailService.saveOrUpdateBatch(historyDetails, historyDetails.size(), false);
        }

        List<OtherContractPayPlanEntity> payPlanList = contractEntity.getPayPlanVos();
        if (null != payPlanList && payPlanList.size() > 0) {
            List<OtherContractPayPlanHistoryEntity> historypayPlan = BeanMapper.mapList(payPlanList, OtherContractPayPlanHistoryEntity.class);
            for (OtherContractPayPlanHistoryEntity hce : historypayPlan) {
                hce.setHistoryId(historyEntity.getId());//记录表主键
                hce.setContractId(entity.getContractId());//原合同主键
                hce.setId(null);
            }
            historyPayPlanService.saveOrUpdateBatch(historypayPlan, historypayPlan.size(), false);
        }

        //同步原条款到记录表
        List<OtherContractClauseEntity> clauseList = contractEntity.getClauseVos();
        if (null != clauseList && clauseList.size() > 0) {
            List<OtherContractClauseHistoryEntity> historyClauses = BeanMapper.mapList(clauseList, OtherContractClauseHistoryEntity.class);
            for (OtherContractClauseHistoryEntity hce : historyClauses) {
                hce.setHistoryId(historyEntity.getId());//记录表主键
                hce.setContractId(entity.getContractId());//原合同主键
                hce.setId(null);
            }
            historyClauseService.saveOrUpdateBatch(historyClauses, historyClauses.size(), false);
        }
    }

    private void savechangeBack(OtherContractChangeEntity entity,Long contractId) {
        //回写原合同清单表
        contractDetailService.deleteByContractId(entity.getContractId());
        List<OtherContractDetailChangeEntity> changeDetailList = entity.getDetailVos();
        if (null != changeDetailList && changeDetailList.size() > 0) {
            List<OtherContractDetailEntity> detailList = BeanMapper.mapList(changeDetailList, OtherContractDetailEntity.class);
            for (OtherContractDetailEntity cde : detailList) {
                cde.setChangeBid(cde.getId());
                cde.setContractId(contractId);
                cde.setId(null);
                //变更类型如果是中止，不能改类型
                if (null == cde.getChangeType() || cde.getChangeType() != 5) {
                    cde.setChangeType(0);
                }
            }
            contractDetailService.saveOrUpdateBatch(detailList, detailList.size(), false);
        }

        List<OtherContractPayPlanChangeEntity> changePayPlanList = entity.getPayPlanVos();
        contractPayPlanService.remove(new QueryWrapper<OtherContractPayPlanEntity>().eq("contract_id", entity.getContractId()), false);
        if (null != changePayPlanList && changePayPlanList.size() > 0) {
            List<OtherContractPayPlanEntity> contractClauses = BeanMapper.mapList(changePayPlanList, OtherContractPayPlanEntity.class);
            for (OtherContractPayPlanEntity cce : contractClauses) {
                cce.setContractId(contractId);
                cce.setId(null);
            }
            contractPayPlanService.saveOrUpdateBatch(contractClauses, contractClauses.size(), false);
        }
        //回写原合同条款表
        List<OtherContractClauseChangeEntity> changeClauseList = entity.getClauseVos();
        contractClauseService.remove(new QueryWrapper<OtherContractClauseEntity>().eq("contract_id", entity.getContractId()), false);
        if (null != changeClauseList && changeClauseList.size() > 0) {
            List<OtherContractClauseEntity> contractClauses = BeanMapper.mapList(changeClauseList, OtherContractClauseEntity.class);
            for (OtherContractClauseEntity cce : contractClauses) {
                cce.setContractId(contractId);
                cce.setId(null);
            }
            contractClauseService.saveOrUpdateBatch(contractClauses, contractClauses.size(), false);
        }
    }

    /**
     * 弃审前事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        return CommonResponse.error("合同变更单暂不支持回退功能!");
    }

    /**
     * 弃审后事件回调
     *
     * @param billId
     * @param state
     * @return
     */
    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
        //TODO
        return CommonResponse.success();
    }

}
